export declare type BootstrapFunction = () => Promise<void | number>;
export declare type ErrorHandlerFunction = (e: Error) => void | Promise<void>;
/**
 * Options for bootstrapping
 */
export interface BootstrapOptions {
    register?: BootstrapFunction;
    run: BootstrapFunction;
    shouldExit?: boolean;
    errorHandler?: ErrorHandlerFunction;
}
/**
 * Default options
 */
export declare const defaultOptions: BootstrapOptions;
/**
 * Bootstrap a function
 *
 * @param options Bootstrapping options
 */
export declare function bootstrap(options: BootstrapOptions): void;
/**
 * Returns a promise that will resolve after bootstrapping is complete.
 * 	You will then be responsible for calling your main entrypoint
 * 	function manually (usually after awaiting this function)
 *
 * @param register Register function
 */
export declare function bootstrapPromise(register: BootstrapFunction): Promise<void>;
