"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.bootstrapPromise = exports.bootstrap = exports.defaultOptions = void 0;
/**
 * Default options
 */
exports.defaultOptions = {
    register: null,
    run: null,
    shouldExit: true,
    errorHandler: console.error
};
/**
 * Bootstrap a function
 *
 * @param options Bootstrapping options
 */
function bootstrap(options) {
    options = Object.assign(Object.assign({}, exports.defaultOptions), options);
    Promise.resolve(options.register ? options.register() : null)
        .then(() => __awaiter(this, void 0, void 0, function* () {
        return yield Promise.resolve(options.run());
    }))
        .then((returned) => {
        if (options.shouldExit) {
            process.exit(returned ? returned : 0);
        }
    })
        .catch((e) => __awaiter(this, void 0, void 0, function* () {
        var _a;
        // Handle or log the error
        yield Promise.resolve(options.errorHandler(e));
        if (options.shouldExit) {
            process.exit((_a = e.code) !== null && _a !== void 0 ? _a : 1);
        }
    }));
}
exports.bootstrap = bootstrap;
/**
 * Returns a promise that will resolve after bootstrapping is complete.
 * 	You will then be responsible for calling your main entrypoint
 * 	function manually (usually after awaiting this function)
 *
 * @param register Register function
 */
function bootstrapPromise(register) {
    return __awaiter(this, void 0, void 0, function* () {
        return yield new Promise((accept, reject) => {
            bootstrap({
                register: register,
                run: () => __awaiter(this, void 0, void 0, function* () { return accept(); }),
                errorHandler: (...e) => __awaiter(this, void 0, void 0, function* () { return reject(...e); }),
                shouldExit: false,
            });
        });
    });
}
exports.bootstrapPromise = bootstrapPromise;
//# sourceMappingURL=index.js.map